@@ -8,7 +8,7 @@ use Regexp::RegGrp;
 
 # =========================================================================== #
 
-our $VERSION = "2.05";
+our $VERSION = "2.06";
 
 our @BOOLEAN_ACCESSORS = ( 'no_compress_comment', 'remove_copyright' );
 
@@ -538,6 +538,9 @@ sub minify {
                         elsif ( $ord > 65 ) {
                             $pd .= '-zA-' . $c;
                         }
+                        elsif ( $ord == 65 ) {
+                            $pd .= '-zA';
+                        }
                         $pd .= ']';
                     }
                 }
@@ -731,7 +734,7 @@ JavaScript::Packer - Perl version of Dean Edwards' Packer.js
 
 =head1 VERSION
 
-Version 2.05
+Version 2.06
 
 =head1 DESCRIPTION
 
